@@ -31,7 +31,7 @@
  */
 
 #include "dnattributeorderconfigwidget.h"
-
+#include "libkleo_debug.h"
 #include "libkleo/dn.h"
 
 #include <KLocalizedString>
@@ -53,16 +53,16 @@ public:
     enum { UUp = 0, Up = 1, Left = 2, Right = 3, Down = 4, DDown = 5 };
 
 #ifndef QT_NO_TREEWIDGET
-    QTreeWidget *availableLV;
-    QTreeWidget *currentLV;
+    QTreeWidget *availableLV = nullptr;
+    QTreeWidget *currentLV = nullptr;
 #endif
     QToolButton *navTB[6];
 
 #ifndef QT_NO_TREEWIDGET
-    QTreeWidgetItem *placeHolderItem;
+    QTreeWidgetItem *placeHolderItem = nullptr;
 #endif
 
-    Kleo::DNAttributeMapper *mapper;
+    Kleo::DNAttributeMapper *mapper = nullptr;
 };
 
 #ifndef QT_NO_TREEWIDGET
@@ -219,7 +219,7 @@ void Kleo::DNAttributeOrderConfigWidget::save() const
 
 void Kleo::DNAttributeOrderConfigWidget::defaults()
 {
-    qDebug() << "Sorry, not implemented: Kleo::DNAttributeOrderConfigWidget::defaults()";
+     qCDebug (LIBKLEO_LOG) << "Sorry, not implemented: Kleo::DNAttributeOrderConfigWidget::defaults()";
 }
 
 void Kleo::DNAttributeOrderConfigWidget::slotAvailableSelectionChanged(QTreeWidgetItem *item)
